import { createStore } from "vuex";
import { getPermissions } from "@/service/user";
import { PERMISSIONNAME_PAGEMODULE } from "../config/pageconfig";
import { getRolesForUser } from "@/service/Withdrawal/withdrawal";

export default createStore({
  state: {
    permissions: null,
    userInfo: null,
    permissionsForApp: null
  },
  mutations: {
    updateUserPermission(state, payload) {
      state.permissions = payload;
    },
    updateUserInfo(state, payload) {
      state.userInfo = payload;
    },
    updatePermissionForApp(state, payload) {
      const { appId, permissions } = payload;
      state.permissionsForApp = state.permissionsForApp || {};
      state.permissionsForApp[appId] = permissions;
    }
  },
  actions: {
    async updateUserPermission({ commit }, payload) {
      const { permissions = [] } = await getPermissions(payload.email);

      console.log("VUEX action updateUserPermission::", permissions);
      commit("updateUserPermission", permissions);
    },
    async fetchPermission({ commit }, { email, appId }) {
      if (appId === "merchant-op-auditing") {
        const permissions = await getRolesForUser(email);
        commit("updatePermissionForApp", { appId, permissions });
        return;
      }
      console.error("无 appId 注册", appId);
    }
  },
  modules: {},
  getters: {
    subPermissions: state => {
      const permissionCol = {};
      (state.permissions || []).forEach(element => {
        PERMISSIONNAME_PAGEMODULE[element.name] &&
          (permissionCol[PERMISSIONNAME_PAGEMODULE[element.name]] =
            element.sub_permissions);
      });
      return permissionCol;
    },
    /**
     *
     * @param {*} module 模块名，可选值： enterprise, lifeNo, role, user
     * @returns
     */
    moduleSubPermissions: state => (module, appId = "") => {
      if (appId !== "") {
        return;
      }

      const permissionCol = {};
      (state.permissions || []).forEach(element => {
        PERMISSIONNAME_PAGEMODULE[element.name] &&
          (permissionCol[PERMISSIONNAME_PAGEMODULE[element.name]] =
            element.sub_permissions);
      });
      return permissionCol[module];
    }
  }
});
